#!/bin/bash

# updated by WIBOON 2556-04-29

if [ -z "$(id -nG|grep -w "root")" ] ; then
  echo "need root, or try: sudo sh $0"
  exit
fi
if [ ! -z "$(grep usrquota /etc/fstab)" ] ; then
  echo "Disk quota system is already installed."
  exit 
fi

sudo apt-get install quota -y

save_exist_file(){
  TARGET="$1"
  if [ -f ${TARGET} ]; then
      INFO=$(ls -clQ --time-style=long-iso ${TARGET})
      CTIME=$(echo ${INFO}|awk '{ print $6"-"$7 }')
      NAME=$(echo "${TARGET}_${CTIME}")
      sudo cp -v ${TARGET} ${NAME}
  fi
}

set_quota_root_partition() {
  sed -i '/^UUID=.* \//s/errors=remount-ro/usrquota,grpquota,errors=remount-ro/g' /etc/fstab
  sudo touch /aquota.user /aquota.group
  sudo chmod 600 /aquota.user /aquota.group
  sudo mount -o remount /
  sudo quotacheck -F vfsv0 -fcvdugm /
  if [ "$?" = "1" ]; then
    echo "quotacheck error, please do the following steps."
    echo "1. please edit grub boot loader to start server in text mode"
    echo "2. reboot server in text mode"
    echo "3. login"
    echo "4. write down and run commands below"
    echo "sudo quotacheck -F vfsv0 -fcvdugm /"
    echo "sudo quotaon -a"
    exit
  fi
  sudo quotaon -a
}

set_quota_home_partition() {
  sed -i '/^UUID=.* \/home/s/defaults/usrquota,grpquota,defaults/g' /etc/fstab
  sudo touch /home/aquota.user /home/aquota.group
  sudo chmod 600 /home/aquota.user /home/aquota.group
  sudo mount -o remount /home
  sudo quotacheck -F vfsv0 -fcvdugm /home
  if [ "$?" = "1" ]; then
    echo "quotacheck error, please do the following steps."
    echo "1. please logoff desktop GUI"
    echo "2. then press ctrl+alt+f1"
    echo "3. login"
    echo "4. write down and run commands below"
    echo "sudo quotacheck -F vfsv0 -fcvdugm /home"
    echo "sudo quotaon -a"
    exit
  fi
  sudo quotaon -a
}

save_exist_file "/etc/fstab"

if [ ! -z "$(grep "/home" /etc/fstab)" ]; then
   FOUND_FSTAB_HOME="yes"
else
   FOUND_FSTAB_HOME="no"
fi

if [ "${FOUND_FSTAB_HOME}" = "yes" ]; then
  while true; do
    read -p "Found! partition /home, do you wish to set quota /home or / ? (y=/home n=/) " yn
    case $yn in
        [Yy]* ) USE_HOME_PAR="yes"; break;;
        [Nn]* ) USE_HOME_PAR="no"; break;;
        * ) echo "Please answer y or n.";;
    esac
  done
  if [ "${USE_HOME_PAR}" = "yes" ]; then
    QUOTA_HOME="yes"
    set_quota_home_partition
  else
    QUOTA_HOME="no"
    set_quota_root_partition
  fi
else
  set_quota_root_partition
fi
echo "filename: /etc/fstab"
echo -n "\033[32m"
echo "------------------------------------------------------------------------"
cat /etc/fstab
echo "------------------------------------------------------------------------"
echo -n "\033[00m"
echo "\033[31m==> PLEASE CHECK /etc/fstab above, you should see a line with usrquota,grpquota\033[00m"
echo -n "\033[32m"
echo "------------------------------------------------------------------------"
if [ "${FOUND_FSTAB_HOME}" = "yes" ]; then
if [ "${QUOTA_HOME}" = "yes" ]; then
  echo "UUID=xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx /home           ext4    usrquota,grpquota,defaults 0 2"
else
  echo "UUID=xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx /               ext4    usrquota,grpquota,errors=remount-ro 0 1"
fi
else
  echo "UUID=xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx /               ext4    usrquota,grpquota,errors=remount-ro 0 1"
fi
echo "------------------------------------------------------------------------"
echo -n "\033[00m"
echo "Disk quota system was installed successfully."

